%    This file is part of the psPack simulation package from the
%    doctoral dissertation "A DAE Formulation for Multi-Zone
%    Application to CVCP Engines" by Per berg. 
%    The dissertation is available at 
%    http://urn.kb.se/resolve?urn=urn:nbn:se:liu:diva-18120
%
%    Copyright (C) 2013  Per berg <per.oberg@liu.se>
%
%    This program is free software; you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation; either version 2 of the License, or
%    (at your option) any later version.
%
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%
%    You should have received a copy of the GNU General Public License along
%    with this program; if not, write to the Free Software Foundation, Inc.,
%    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

function [h cp cv R dRdp dRdT dudp dudX dRdX]=psThermProp(p,T,Xgc,outputs)
% psThermProp - Simple approximation for the thermodynamic properties
%
% [h cp cv R dRdp dRdT dudp dudX dRdX]=psThermProp(p,T,Xgc,outputs)
% 
% Simple thermodynamic properties based on CHEPP. It uses isooctane as
% fuel and assumes ideal gas conditions, but has a realistic enthalpy
% difference between burned and unburned gases. The intended use of this
% function is as a fast thermodynamic property calculator for simulation
% programs. 
%
%  In: 
%    p       = Pressure        1x1
%    T       = Temperature     Nx1
%    Xgc     = Gas composition Nx4
%              [x_uf x_ua x_bf  x_ba]
%    outputs = Specifies wanted outputs 1x9
%  Out: 
%   h    = Nx1 - enthalpies
%   cp   = Nx1 - specific heats (constant pressure)
%   cv   = Nx1 - specific heats (constant volume)
%   R    = Nx1 - Ideal gas constants
%   dRdp = Nx1 - Partial derivatives of the gas constant wrt p
%   dRdT = Nx1 - Partial derivatives or the gas constant wrt T
%   dudp = Nx1 - Partial derivatives of the specific internal energy wrt p
%   dudX = Nx4 - Partial derivatives of the specific internal energy wrt X
%   dRdX = Nx4 - Partial derivatives of the gas constant wrt X


% 2008-04-16 Per berg, oberg@isy.liu.se 

oneVec = ones(size(T));
zeroVec = zeros(size(T));

cp = 1.0378e+03*oneVec;
cv = 762.9870*oneVec;
R  = 274.8130*oneVec;
h  = 1.0378e+03*T-Xgc(:,3)*44759000;



dRdT = zeroVec;
dRdp = zeroVec;
dudp = zeroVec;
dudX = zeros(length(T),4);
dudX(:,3) = -44759000;
dRdX = zeros(length(T),4);
